---
---
// Note: Jekyll needs the front matter above to make this file work
.a4b1e3f8d9 {opacity: 1;}  // This line is intended to silence the error warning message in VS Code

@import url('https://fonts.googleapis.com/css2?family=Caveat&display=swap');
$font: 'Caveat', cursive;

$mobile-width: 850px;

@import "constants";  // Will be created during compilation

body {
	margin: 0;  // Remove the unwanted margin
    overflow-y: scroll;  // Keep showing the scrollbar to prevent glitching
	// Main font
    font-family: system-ui, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, 'Open Sans', 'Helvetica Neue', sans-serif;
	// Default page color
    background-color: hsl($hue-signature, 15%, 91%);;
    // Default font color
    color: #2f322f;

	// Main scrollbar
	&::-webkit-scrollbar {
		width: 7px;
		background-color: inherit;
	}
	&::-webkit-scrollbar-thumb {
		background-color: hsl($hue-signature, 21%, 71%);
		&:hover {
			background-color: hsl($hue-signature, 21%, 50%);
		}
	}
}

main {
	min-height: 100vh;
	margin: 0 auto;
	width: 68%;
	@media (max-width: $mobile-width) {width: 91%;}

	a {
		color: inherit;
		&:hover {
			color: hsl($hue-signature, 50%, 50%);
		}
	}

	// img {
	// 	max-width: 100%;
	// }
}

// I suspect these imports must be placed at the bottom,
// or some SCSS styles might not be applied to them.
// 
//   					~ Nicholas @ July 12, 2023
@import "header";
@import "footer";

// Syntax highlighting
@import "sass-code-highlight.scss";